import { ComponentFactoryResolver, Injectable, Injector } from '@angular/core';
import { RebirthNGConfig } from '../rebirth-ng.config';
import { OverlayComponent } from './overlay.component';
import { DomSanitizer } from '@angular/platform-browser';
var OverlayService = (function () {
    function OverlayService(rebirthNGConfig, componentFactoryResolver, injector, domSanitizer) {
        this.rebirthNGConfig = rebirthNGConfig;
        this.componentFactoryResolver = componentFactoryResolver;
        this.injector = injector;
        this.domSanitizer = domSanitizer;
        this.overlayCount = 0;
    }
    OverlayService.prototype.open = function (options) {
        if (!this.overlayCount++) {
            this.createOverlay(options);
        }
    };
    OverlayService.prototype.createOverlay = function (options) {
        var rootContainer = options.rootContainer || this.rebirthNGConfig.rootContainer;
        if (!rootContainer) {
            throw new Error('Should setup ViewContainerRef on modal overlay or rebirth config service!');
        }
        if (options.html && (typeof options.html === 'string')) {
            options.html = this.domSanitizer.bypassSecurityTrustHtml(options.html);
        }
        var componentFactory = this.componentFactoryResolver.resolveComponentFactory(OverlayComponent);
        var injector = options.injector || this.injector;
        this.overlayRef = rootContainer.createComponent(componentFactory, rootContainer.length, injector);
        var cmp = this.overlayRef.instance;
        cmp.addContent(options);
    };
    OverlayService.prototype.close = function () {
        this.overlayCount = this.overlayCount > 0 ? this.overlayCount - 1 : 0;
        if (this.overlayCount < 1 && this.overlayRef) {
            this.overlayRef.destroy();
        }
    };
    return OverlayService;
}());
export { OverlayService };
OverlayService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
OverlayService.ctorParameters = function () { return [
    { type: RebirthNGConfig, },
    { type: ComponentFactoryResolver, },
    { type: Injector, },
    { type: DomSanitizer, },
]; };
//# sourceMappingURL=overlay.service.js.map